@@ -15,7 +15,7 @@ from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
 
-from netbox_storage.models import Drive, PhysicalVolume
+from netbox_storage.models import Drive, PhysicalVolume, VolumeGroup, LinuxDevice
 
 
 class PhysicalVolumeForm(NetBoxModelForm):
@@ -24,11 +24,23 @@ class PhysicalVolumeForm(NetBoxModelForm):
         label="Description",
         help_text="Short Description e.g. PhysicalVolume 1 on SSD Cluster",
     )
+    linux_device = DynamicModelChoiceField(
+        queryset=LinuxDevice.objects.all(),
+        label="Linux Device",
+        help_text="The parent Object of the Device e.g. Drive, LinuxDevice, LV",
+    )
+    vg = DynamicModelChoiceField(
+        queryset=VolumeGroup.objects.all(),
+        label="Volume Group",
+        help_text="The parent Object of the Device e.g. Drive, LinuxDevice, LV",
+    )
 
     class Meta:
         model = PhysicalVolume
 
         fields = (
+            'linux_device',
+            'vg',
             "description",
         )
 
